@@ -4,7 +4,8 @@ import sys
 if sys.version_info < (3, 7):
   sys.exit("Python %s.%s or later is required.\n" %(3, 7))
 
-import argparse, glob, itertools, lsbtools, os, re, socket, textwrap
+import argparse, glob, itertools, os, re, socket, textwrap
+from . import lsbtools
 from shutil import copyfile
 
 def inst_inet(argobject):
